@@ -13,14 +13,12 @@
 ##############################################################################
 """Size adapters for testing
 """
-from __future__ import absolute_import
-
 from zope.interface import implementer
 from zope.size.interfaces import ISized
 
 
 @implementer(ISized)
-class SimpleContentSize(object):
+class SimpleContentSize:
     """Size for ``SimpleContent`` objects."""
 
     def __init__(self, context):
@@ -34,7 +32,7 @@ class SimpleContentSize(object):
 
 
 @implementer(ISized)
-class FancyContentSize(object):
+class FancyContentSize:
     """Size for ``SimpleContent`` objects."""
 
     def __init__(self, context):
