@@ -1,11 +1,7 @@
-# -*- coding: utf-8 -*-
-
 import traceback
 import unittest
 from io import BytesIO
 
-from six import PY2
-
 from zExceptions import BadRequest
 from zExceptions import Forbidden
 from zExceptions import InternalError
@@ -16,6 +12,7 @@ from zExceptions import Unauthorized
 from ..HTTPResponse import encode_params
 from ..HTTPResponse import encode_words
 from ..HTTPResponse import header_encoding_registry
+from ..HTTPResponse import make_content_disposition
 
 
 class HTTPResponseTests(unittest.TestCase):
@@ -91,7 +88,7 @@ class HTTPResponseTests(unittest.TestCase):
                          'application/foo; charset: something')
 
     def test_ctor_charset_unicode_body_application_header(self):
-        BODY = u'\xe4rger'
+        BODY = '\xe4rger'
         response = self._makeOne(body=BODY,
                                  headers={'content-type': 'application/foo'})
         self.assertEqual(response.headers.get('content-type'),
@@ -99,7 +96,7 @@ class HTTPResponseTests(unittest.TestCase):
         self.assertEqual(response.body, BODY.encode('utf-8'))
 
     def test_ctor_charset_unicode_body_application_header_diff_encoding(self):
-        BODY = u'\xe4rger'
+        BODY = '\xe4rger'
         response = self._makeOne(body=BODY,
                                  headers={'content-type':
                                           'application/foo; charset=utf-8'})
@@ -109,8 +106,8 @@ class HTTPResponseTests(unittest.TestCase):
         self.assertEqual(response.body, BODY.encode('utf-8'))
 
     def test_ctor_body_recodes_to_match_content_type_charset(self):
-        xml = (u'<?xml version="1.0" encoding="iso-8859-15" ?>\n'
-               u'<foo><bar/></foo>')
+        xml = ('<?xml version="1.0" encoding="iso-8859-15" ?>\n'
+               '<foo><bar/></foo>')
         response = self._makeOne(
             body=xml, headers={
                 'content-type': 'text/xml; charset=utf-8'})
@@ -118,8 +115,8 @@ class HTTPResponseTests(unittest.TestCase):
                          xml.replace('iso-8859-15', 'utf-8').encode('utf-8'))
 
     def test_ctor_body_already_matches_charset_unchanged(self):
-        xml = (u'<?xml version="1.0" encoding="iso-8859-15" ?>\n'
-               u'<foo><bar/></foo>')
+        xml = ('<?xml version="1.0" encoding="iso-8859-15" ?>\n'
+               '<foo><bar/></foo>')
         response = self._makeOne(
             body=xml, headers={
                 'content-type': 'text/xml; charset=iso-8859-15'})
@@ -355,10 +352,10 @@ class HTTPResponseTests(unittest.TestCase):
 
     def test_setCookie_handle_unicode_values(self):
         response = self._makeOne()
-        response.setCookie('foo', u'bar')
+        response.setCookie('foo', 'bar')
         cookie = response.cookies.get('foo', None)
         self.assertEqual(len(cookie), 2)
-        self.assertEqual(cookie.get('value'), u'bar')
+        self.assertEqual(cookie.get('value'), 'bar')
 
         cookie_list = response._cookie_list()
         self.assertEqual(len(cookie_list), 1)
@@ -625,7 +622,7 @@ class HTTPResponseTests(unittest.TestCase):
     def test_setBody_object_with_asHTML(self):
         HTML = '<html><head></head><body></body></html>'
 
-        class Dummy(object):
+        class Dummy:
             def asHTML(self):
                 return HTML
         response = self._makeOne()
@@ -637,8 +634,8 @@ class HTTPResponseTests(unittest.TestCase):
         self.assertEqual(response.getHeader('Content-Length'), str(len(HTML)))
 
     def test_setBody_object_with_unicode(self):
-        HTML = (u'<html><head></head><body>'
-                u'<h1>Tr\u0039s Bien</h1></body></html>')
+        HTML = ('<html><head></head><body>'
+                '<h1>Tr\u0039s Bien</h1></body></html>')
         ENCODED = HTML.encode('utf-8')
         response = self._makeOne()
         result = response.setBody(HTML)
@@ -759,7 +756,7 @@ class HTTPResponseTests(unittest.TestCase):
         self.assertTrue(response._locked_status)
 
     def test_redirect_nonascii(self):
-        URL = u'http://example.com/\xe4'
+        URL = 'http://example.com/\xe4'
         BYTES_URL = URL.encode('UTF-8')
         ENC_URL = 'http://example.com/%C3%A4'
 
@@ -795,13 +792,13 @@ class HTTPResponseTests(unittest.TestCase):
         self._redirectURLCheck(url)
 
     def test__encode_unicode_no_content_type_uses_default_encoding(self):
-        UNICODE = u'<h1>Tr\u0039s Bien</h1>'
+        UNICODE = '<h1>Tr\u0039s Bien</h1>'
         response = self._makeOne()
         self.assertEqual(response._encode_unicode(UNICODE),
                          UNICODE.encode('UTF8'))
 
     def test__encode_unicode_w_content_type_no_charset_updates_charset(self):
-        UNICODE = u'<h1>Tr\u0039s Bien</h1>'
+        UNICODE = '<h1>Tr\u0039s Bien</h1>'
         response = self._makeOne()
         response.setHeader('Content-Type', 'text/html')
         self.assertEqual(response._encode_unicode(UNICODE),
@@ -809,7 +806,7 @@ class HTTPResponseTests(unittest.TestCase):
         response.getHeader('Content-Type', 'text/html; charset=UTF8')
 
     def test__encode_unicode_w_content_type_w_charset(self):
-        UNICODE = u'<h1>Tr\u0039s Bien</h1>'
+        UNICODE = '<h1>Tr\u0039s Bien</h1>'
         response = self._makeOne()
         response.setHeader('Content-Type', 'text/html; charset=latin1')
         self.assertEqual(response._encode_unicode(UNICODE),
@@ -817,9 +814,9 @@ class HTTPResponseTests(unittest.TestCase):
         response.getHeader('Content-Type', 'text/html; charset=latin1')
 
     def test__encode_unicode_w_content_type_w_charset_xml_preamble(self):
-        PREAMBLE = u'<?xml version="1.0" ?>'
-        ELEMENT = u'<element>Tr\u0039s Bien</element>'
-        UNICODE = u'\n'.join([PREAMBLE, ELEMENT])
+        PREAMBLE = '<?xml version="1.0" ?>'
+        ELEMENT = '<element>Tr\u0039s Bien</element>'
+        UNICODE = '\n'.join([PREAMBLE, ELEMENT])
         response = self._makeOne()
         response.setHeader('Content-Type', 'text/html; charset=latin1')
         self.assertEqual(response._encode_unicode(UNICODE),
@@ -1032,11 +1029,11 @@ class HTTPResponseTests(unittest.TestCase):
         response.redirect('http://example.com/')
         status, headers = response.finalize()
         self.assertEqual(status, '302 Found')
-        expected = set([
+        expected = {
             ('X-Powered-By', 'Zope (www.zope.org), Python (www.python.org)'),
             ('Content-Length', '0'),
             ('Location', 'http://example.com/'),
-        ])
+        }
         self.assertEqual(set(headers), expected)
 
     def test_listHeaders_empty(self):
@@ -1125,14 +1122,14 @@ class HTTPResponseTests(unittest.TestCase):
         headers = dict(response.listHeaders())
         cookie_header = headers.pop('Set-Cookie')
         headers = list(headers.items())
-        expected = set([
+        expected = {
             ('X-Powered-By', 'Zope (www.zope.org), Python (www.python.org)'),
-        ])
+        }
         self.assertEqual(set(headers), expected)
         self.assertEqual(
             set(cookie_header.split('; ')),
-            set(['qux="deleted"', 'Path=/', 'Max-Age=0',
-                 'Expires=Wed, 31 Dec 1997 23:59:59 GMT'])
+            {'qux="deleted"', 'Path=/', 'Max-Age=0',
+             'Expires=Wed, 31 Dec 1997 23:59:59 GMT'}
         )
 
     def test_listHeaders_after_addHeader(self):
@@ -1151,11 +1148,11 @@ class HTTPResponseTests(unittest.TestCase):
         response = self._makeOne()
         response.setBody(b'BLAH')
         headers = response.listHeaders()
-        expected = set([
+        expected = {
             ('X-Powered-By', 'Zope (www.zope.org), Python (www.python.org)'),
             ('Content-Length', '4'),
             ('Content-Type', 'text/plain; charset=utf-8'),
-        ])
+        }
         self.assertEqual(set(headers), expected)
 
     def test___str__already_wrote(self):
@@ -1168,12 +1165,12 @@ class HTTPResponseTests(unittest.TestCase):
         result = bytes(response)
         lines = result.split(b'\r\n')
         self.assertEqual(len(lines), 5)
-        expected = set([
+        expected = {
             b'Status: 200 OK',
             b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
             b'Content-Length: 0',
             b'',
-        ])
+        }
         self.assertEqual(set(lines), expected)
 
     def test___str__existing_content_length(self):
@@ -1184,12 +1181,12 @@ class HTTPResponseTests(unittest.TestCase):
         result = bytes(response)
         lines = result.split(b'\r\n')
         self.assertEqual(len(lines), 5)
-        expected = set([
+        expected = {
             b'Status: 200 OK',
             b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
             b'Content-Length: 42',
             b'',
-        ])
+        }
         self.assertEqual(set(lines), expected)
 
     def test___str__existing_transfer_encoding(self):
@@ -1199,12 +1196,12 @@ class HTTPResponseTests(unittest.TestCase):
         result = bytes(response)
         lines = result.split(b'\r\n')
         self.assertEqual(len(lines), 5)
-        expected = set([
+        expected = {
             b'Status: 200 OK',
             b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
             b'Transfer-Encoding: slurry',
             b'',
-        ])
+        }
         self.assertEqual(set(lines), expected)
 
     def test___str__after_setHeader(self):
@@ -1213,13 +1210,13 @@ class HTTPResponseTests(unittest.TestCase):
         result = bytes(response)
         lines = result.split(b'\r\n')
         self.assertEqual(len(lines), 6)
-        expected = set([
+        expected = {
             b'Status: 200 OK',
             b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
             b'Content-Length: 0',
             b'X-Consistency: Foolish',
             b'',
-        ])
+        }
         self.assertEqual(set(lines), expected)
 
     def test___str__after_setHeader_literal(self):
@@ -1228,13 +1225,13 @@ class HTTPResponseTests(unittest.TestCase):
         result = bytes(response)
         lines = result.split(b'\r\n')
         self.assertEqual(len(lines), 6)
-        expected = set([
+        expected = {
             b'Status: 200 OK',
             b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
             b'Content-Length: 0',
             b'X-consistency: Foolish',
             b'',
-        ])
+        }
         self.assertEqual(set(lines), expected)
 
     def test___str__after_redirect(self):
@@ -1243,13 +1240,13 @@ class HTTPResponseTests(unittest.TestCase):
         result = bytes(response)
         lines = result.split(b'\r\n')
         self.assertEqual(len(lines), 6)
-        expected = set([
+        expected = {
             b'Status: 302 Found',
             b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
             b'Content-Length: 0',
             b'Location: http://example.com/',
             b'',
-        ])
+        }
         self.assertEqual(set(lines), expected)
 
     def test___str__after_setCookie_appendCookie(self):
@@ -1259,13 +1256,13 @@ class HTTPResponseTests(unittest.TestCase):
         result = bytes(response)
         lines = result.split(b'\r\n')
         self.assertEqual(len(lines), 6)
-        expected = set([
+        expected = {
             b'Status: 200 OK',
             b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
             b'Content-Length: 0',
             b'Set-Cookie: foo="bar%3Abaz"; Path=/',
             b'',
-        ])
+        }
         self.assertEqual(set(lines), expected)
 
     def test___str__after_expireCookie(self):
@@ -1276,18 +1273,18 @@ class HTTPResponseTests(unittest.TestCase):
         cookie_line = [line for line in lines if b'Set-Cookie' in line][0]
         other_lines = [line for line in lines if b'Set-Cookie' not in line]
         self.assertEqual(len(lines), 6)
-        expected = set([
+        expected = {
             b'Status: 200 OK',
             b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
             b'Content-Length: 0',
             b'',
-        ])
+        }
         self.assertEqual(set(other_lines), expected)
         cookie_value = cookie_line.split(b': ', 1)[-1]
         self.assertEqual(
             set(cookie_value.split(b'; ')),
-            set([b'qux="deleted"', b'Path=/', b'Max-Age=0',
-                 b'Expires=Wed, 31 Dec 1997 23:59:59 GMT'])
+            {b'qux="deleted"', b'Path=/', b'Max-Age=0',
+             b'Expires=Wed, 31 Dec 1997 23:59:59 GMT'}
         )
 
     def test___str__after_addHeader(self):
@@ -1297,14 +1294,14 @@ class HTTPResponseTests(unittest.TestCase):
         result = bytes(response)
         lines = result.split(b'\r\n')
         self.assertEqual(len(lines), 7)
-        expected = set([
+        expected = {
             b'Status: 200 OK',
             b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
             b'Content-Length: 0',
             b'X-Consistency: Foolish',
             b'X-Consistency: Oatmeal',
             b'',
-        ])
+        }
         self.assertEqual(set(lines), expected)
 
     def test___str__w_body(self):
@@ -1313,14 +1310,14 @@ class HTTPResponseTests(unittest.TestCase):
         result = bytes(response)
         lines = result.split(b'\r\n')
         self.assertEqual(len(lines), 6)
-        expected = set([
+        expected = {
             b'Status: 200 OK',
             b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
             b'Content-Length: 4',
             b'Content-Type: text/plain; charset=utf-8',
             b'BLAH',
             b'',
-        ])
+        }
         self.assertEqual(set(lines), expected)
         # Body is separated by a newline
         self.assertEqual(lines[4], b'')
@@ -1333,13 +1330,13 @@ class HTTPResponseTests(unittest.TestCase):
         self.assertTrue(response._wrote)
         lines = stdout.getvalue().split(b'\r\n')
         self.assertEqual(len(lines), 5)
-        expected = set([
+        expected = {
             b'Status: 200 OK',
             b'X-Powered-By: Zope (www.zope.org), Python (www.python.org)',
             b'Content-Length: 0',
             b'Kilroy was here!',
             b'',
-        ])
+        }
         self.assertEqual(set(lines), expected)
         # Body is separated by a newline
         self.assertEqual(lines[3], b'')
@@ -1365,10 +1362,8 @@ class HTTPResponseTests(unittest.TestCase):
             self.assertEqual(response.errmsg, 'Internal Server Error')
 
     def test_exception_500_text(self):
-        message = u'ERROR \xe4 VALUE'
+        message = 'ERROR \xe4 VALUE'
         exc = AttributeError(message)
-        # This gets called deep down in the zExceptions.ExceptionFormatter
-        # and produces different results in Python 2/3.
         expected = traceback.format_exception_only(
             exc.__class__, exc)[0].encode('utf-8')
         response = self._makeOne()
@@ -1382,30 +1377,54 @@ class HTTPResponseTests(unittest.TestCase):
 
     def test_isHTML_not_decodable_bytes(self):
         response = self._makeOne()
-        self.assertFalse(response.isHTML(u'bïñårÿ'.encode('latin1')))
+        self.assertFalse(response.isHTML('bïñårÿ'.encode('latin1')))
 
     def test_header_encoding(self):
         r = self._makeOne()
-        ae = u"ä"
-        ae_enc = ae.encode("ISO-8859-1") if PY2 else ae
-        r.setHeader("unencoded1", ae)
-        r.setHeader("content-disposition", u"a; p=€")
-        r.addHeader("unencoded2", ae)
-        r.addHeader("content-disposition", u"a2; p2=€")
+        r.setHeader("unencoded1", "€")
+        r.setHeader("content-disposition", "a; p=€")
+        r.addHeader("unencoded2", "€")
+        r.addHeader("content-disposition", "a2; p2=€")
         r.addHeader("bytes", b"abc")
         hdrs = r.listHeaders()[1:]  # drop `X-Powered...`
         shdrs, ahdrs = dict(hdrs[:2]), dict(hdrs[2:])
         # for some reasons, `set` headers change their name
         #   while `add` headers do not
-        self.assertEqual(shdrs["Unencoded1"], ae_enc)
-        self.assertEqual(ahdrs["unencoded2"], ae_enc)
+        self.assertEqual(shdrs["Unencoded1"], "€")
+        self.assertEqual(ahdrs["unencoded2"], "€")
         self.assertEqual(shdrs["Content-Disposition"],
-                         u"a; p=?; p*=utf-8''%E2%82%AC")
+                         "a; p=?; p*=utf-8''%E2%82%AC")
         self.assertEqual(ahdrs["content-disposition"],
-                         u"a2; p2=?; p2*=utf-8''%E2%82%AC")
+                         "a2; p2=?; p2*=utf-8''%E2%82%AC")
         self.assertEqual(ahdrs["bytes"], "abc")
 
 
+class MakeDispositionHeaderTests(unittest.TestCase):
+
+    def test_ascii(self):
+        self.assertEqual(
+            make_content_disposition('inline', 'iq.png'),
+            'inline; filename="iq.png"')
+
+    def test_latin_one(self):
+        self.assertEqual(
+            make_content_disposition('inline', 'Dänemark.png'),
+            'inline; filename="b\'Dnemark.png\'"; filename*=UTF-8\'\'D%C3%A4nemark.png'  # noqa: E501
+        )
+
+    def test_unicode(self):
+        """HTTP headers need to be latin-1 compatible
+
+        In order to offer file downloads which contain unicode file names,
+        the file name has to be treated in a special way, see
+        https://stackoverflow.com/questions/1361604 .
+        """
+        self.assertEqual(
+            make_content_disposition('inline', 'ıq.png'),
+            'inline; filename="b\'q.png\'"; filename*=UTF-8\'\'%C4%B1q.png'
+        )
+
+
 class TestHeaderEncodingRegistry(unittest.TestCase):
     def setUp(self):
         self._copy = header_encoding_registry.copy()
@@ -1424,38 +1443,38 @@ class TestHeaderEncodingRegistry(unittest.TestCase):
             return param
         header_encoding_registry.register("my-header", encode, param=1)
         # non-ISO-8859-1 encoded
-        self.assertEqual(header_encoding_registry.encode("my-header", u"€"),
+        self.assertEqual(header_encoding_registry.encode("my-header", "€"),
                          1)
         # ISO-8859-1 not encoded
-        self.assertEqual(header_encoding_registry.encode("my-header", u"ä"),
-                         u"ä")
+        self.assertEqual(header_encoding_registry.encode("my-header", "ä"),
+                         "ä")
         # unregistered not encoded
-        self.assertEqual(header_encoding_registry.encode("my-header2", u"€"),
-                         u"€")
+        self.assertEqual(header_encoding_registry.encode("my-header2", "€"),
+                         "€")
         # test header name not case sensitive
-        self.assertEqual(header_encoding_registry.encode("My-Header", u"€"),
+        self.assertEqual(header_encoding_registry.encode("My-Header", "€"),
                          1)
         # default
         header_encoding_registry.register(None, encode, param=2)
-        self.assertEqual(header_encoding_registry.encode("my-header2", u"€"),
+        self.assertEqual(header_encoding_registry.encode("my-header2", "€"),
                          2)
-        self.assertEqual(header_encoding_registry.encode("my-header", u"€"),
+        self.assertEqual(header_encoding_registry.encode("my-header", "€"),
                          1)
 
     def test_encode_words(self):
-        self.assertEqual(encode_words(u"ä"), "=?utf-8?b?w6Q=?=")
+        self.assertEqual(encode_words("ä"), "=?utf-8?b?w6Q=?=")
 
     def test_encode_params(self):
-        self.assertEqual(encode_params(u'abc; p1=1; p2="2"; p3="€"; p4=€; '
-                                       u'p5="€"; p5*=5'),
-                         u'abc; p1=1; p2="2"; p3="?"; p4=?; p5="?"; p5*=5; '
-                         u'p3*=utf-8\'\'%E2%82%AC; p4*=utf-8\'\'%E2%82%AC')
+        self.assertEqual(encode_params('abc; p1=1; p2="2"; p3="€"; p4=€; '
+                                       'p5="€"; p5*=5'),
+                         'abc; p1=1; p2="2"; p3="?"; p4=?; p5="?"; p5*=5; '
+                         'p3*=utf-8\'\'%E2%82%AC; p4*=utf-8\'\'%E2%82%AC')
 
     def test_case_insensitivity(self):
         header_encoding_registry.register("HdR", lambda value: 0)
         # Note: case insensitivity not implemented for `dict` methods
         self.assertIn("hdr", header_encoding_registry)
-        self.assertEqual(header_encoding_registry.encode("HDR", u"€"), 0)
+        self.assertEqual(header_encoding_registry.encode("HDR", "€"), 0)
         header_encoding_registry.unregister("hDr")
         header_encoding_registry.unregister("hDr")  # no exception
         self.assertNotIn("hdr", header_encoding_registry)
